@@ -1,9 +1,6 @@
 import logging
 
-from feeluown.app import App
-
 from .provider import provider
-from .ui import UiManager
 
 __alias__ = 'QQ 音乐'
 __feeluown_version__ = '1.1.0'
@@ -11,17 +8,18 @@ __version__ = '0.3a0'
 __desc__ = 'QQ 音乐'
 
 logger = logging.getLogger(__name__)
-ui_mgr = None
 
 
 def enable(app):
-    global ui_mgr
     app.library.register(provider)
-    if app.mode & App.GuiMode:
-        ui_mgr = ui_mgr or UiManager(app)
+    if app.mode & app.GuiMode:
+        from .provider_ui import ProviderUI
+
+        provider_ui = ProviderUI(app)
+        app.pvd_ui_mgr.register(provider_ui)
 
 
 def disable(app):
     app.library.deregister(provider)
-    if app.mode & App.GuiMode:
+    if app.mode & app.GuiMode:
         app.providers.remove(provider.identifier)
